@@ -29,6 +29,23 @@ from dstk.pytorch import (check_tensor, CallbackInterface, CallbackHandler,
                           FitState, FitControl, DEFAULT_CALLBACKS)
 from dstk.utils.errors import DivergenceError
 
+
+def _getattr(model, attr):
+    attr_split = attr.split('.')
+    if len(attr_split) > 1:
+        model = getattr(model, attr_split[0])
+        return _getattr(model, '.'.join(attr_split[1:]))
+    return getattr(model, attr_split[0])
+
+
+def _setattr(model, attr, value):
+    attr_split = attr.split('.')
+    if len(attr_split) > 1:
+        model = getattr(model, attr_split[0])
+        return _setattr(model, '.'.join(attr_split[1:], value))
+    setattr(model, attr_split[0], value)
+
+
 class BaseEnvironnement(BaseEstimator):
     r"""
     Classe d'environnement PyTorch pour être compatible Scikit-Learn.
@@ -157,7 +174,7 @@ class BaseEnvironnement(BaseEstimator):
             state_optimizer = None
         if attr_list:
             state_attribut = {
-                attr: getattr(self, attr) for attr in attr_list
+                attr: _getattr(self, attr) for attr in attr_list
             }
         else:
             state_attribut = None
@@ -233,7 +250,7 @@ class BaseEnvironnement(BaseEstimator):
             self.optimizer.load_state_dict(state_optimizer)
         if state_attribut:
             for key, item in state_attribut.items():
-                setattr(self, key, item);
+                _setattr(self, key, item);
         self.eval()
         return self
 
@@ -287,7 +304,7 @@ class BaseEnvironnement(BaseEstimator):
             model.optimizer.load_state_dict(state_optimizer)
         if state_attribut:
             for key, item in state_attribut.items():
-                setattr(model, key, item)
+                _setattr(model, key, item)
         model.eval()
         return model
 
